---
name: Feature request
about: Request a new feature

---

# Feature request

<!-- Thanks for coming up with a proposal! -->

## Thesis

<!-- What exactly do you propose? Please, provide code examples. -->

## Reasoning

<!--
Why do you think this is a good idea?

Please, include some strong points and considerations.
-->
